@@ -127,6 +127,32 @@ mp_setup_media_link_pad_formats(struct device_info *dev_info,
         }
 }
 
+static int
+get_bridge_fd(const MPDevice *device)
+{
+        const struct media_v2_entity *bridge =
+                mp_device_find_entity_type(device, MEDIA_ENT_F_VID_IF_BRIDGE);
+        if (!bridge) {
+                g_printerr("Could not find device bridge entity\n");
+                return -1;
+        }
+
+        const struct media_v2_interface *bridge_interface =
+                mp_device_find_entity_interface(device, bridge->id);
+        char dev_name[260];
+        if (!mp_find_device_path(bridge_interface->devnode, dev_name, 260)) {
+                g_printerr("Could not find bridge path\n");
+                return -1;
+        }
+
+        int bridge_fd = open(dev_name, O_RDWR);
+        if (bridge_fd == -1) {
+                g_printerr("Could not open %s: %s\n", dev_name, strerror(errno));
+        }
+
+        return bridge_fd;
+}
+
 static void
 setup_camera(MPDeviceList **device_list, const struct mp_camera_config *config)
 {
@@ -163,8 +189,15 @@ setup_camera(MPDeviceList **device_list, const struct mp_camera_config *config)
                         exit(EXIT_FAILURE);
                 }
 
+                const struct media_v2_entity *bridge = mp_device_find_entity_type(
+                        info->device, MEDIA_ENT_F_VID_IF_BRIDGE);
+                if (!bridge) {
+                        g_printerr("Could not find device bridge entity\n");
+                        bridge = entity;
+                }
+
                 const struct media_v2_pad *pad =
-                        mp_device_get_pad_from_entity(info->device, entity->id);
+                        mp_device_get_pad_from_entity(info->device, bridge->id);
                 info->interface_pad_id = pad->id;
 
                 const struct media_v2_interface *interface =
@@ -228,7 +261,9 @@ setup_camera(MPDeviceList **device_list, const struct mp_camera_config *config)
                         exit(EXIT_FAILURE);
                 }
 
-                info->camera = mp_camera_new(dev_info->video_fd, info->fd);
+                int bridge_fd = get_bridge_fd(dev_info->device);
+                info->camera =
+                        mp_camera_new(dev_info->video_fd, info->fd, bridge_fd);
 
                 // Start with the capture format, this works around a bug with
                 // the ov5640 driver where it won't allow setting the preview
@@ -385,12 +420,12 @@ capture(MPPipeline *pipeline, const void *data)
                 info->camera, V4L2_CID_EXPOSURE_AUTO, V4L2_EXPOSURE_MANUAL);
 
         // Get current gain to calculate a burst length;
-        // with low gain there's 2, with the max automatic gain of the ov5640
+        // with low gain there's 3, with the max automatic gain of the ov5640
         // the value seems to be 248 which creates a 5 frame burst
         // for manual gain you can go up to 11 frames
         gain = mp_camera_control_get_int32(info->camera, V4L2_CID_GAIN);
         gain_norm = (float)gain / (float)info->gain_max;
-        burst_length = (int)fmax(sqrt(gain_norm) * 10, 1) + 1;
+        burst_length = (int)fmax(sqrt(gain_norm) * 10, 2) + 1;
         captures_remaining = burst_length;
 
         // Change camera mode for capturing
